@@ -17,10 +17,10 @@ require 'mkmf-gnome2'
 setup_windows(module_name, base_dir)
 
 unless required_pkg_config_package([package_id, 2, 12, 0],
-                                   :altlinux => "glib2-devel",
+                                   :alt_linux => "glib2-devel",
                                    :debian => "libglib2.0-dev",
                                    :redhat => "glib2-devel",
-                                   :arch => "glib2",
+                                   :arch_linux => "glib2",
                                    :homebrew => "glib",
                                    :macports => "glib2")
   exit(false)
@@ -41,14 +41,13 @@ have_func("rb_check_array_type", ruby_header)
 have_func("rb_check_hash_type", ruby_header)
 have_func("rb_exec_recursive", ruby_header)
 have_func("rb_errinfo", ruby_header)
-have_func("rb_sourcefile", ruby_header)
-have_func("rb_sourceline", ruby_header)
-have_func("ruby_set_current_source", ruby_header)
 have_func("rb_thread_call_without_gvl", ruby_header)
 have_func("ruby_native_thread_p", ruby_header)
 have_func("rb_thread_call_with_gvl", ruby_header)
 have_func("rb_gc_register_mark_object", ruby_header)
 have_func("rb_exc_new_str", ruby_header)
+# For Ruby 2.1. TODO: Remove this when we drop Ruby 2.1 support.
+have_func("rb_enc_str_new_static", ruby_header)
 
 have_var("curr_thread", [ruby_header, "node.h"])
 have_var("rb_curr_thread", [ruby_header, "node.h"])
